@@ -166,6 +166,7 @@ class AddImage(BrowserView):
                     id=time.time(),
                     title=file_name,
                     image=file_data,
+                    excludeFromNav=self.context.getAuto_exclude_from_nav(),
                 )
 
                 # It's necessary to save the object creation before we can rename it
@@ -175,9 +176,6 @@ class AddImage(BrowserView):
                 oid = INameChooser(self.context).chooseName(file_name, new_image)
                 new_image.setId(oid)
                 new_image.reindexObject()
-
-                new_image.setExcludeFromNav(self.context.getAuto_exclude_from_nav())
-                new_image.update()
             except:
                 return json.dumps({u'error': _(u"The file %(file)s already exists") % {'file' : file_name}})
 
