@@ -52,6 +52,17 @@ ImageGallerySchema = folder.ATFolderSchema.copy() + atapi.Schema((
         default=5,
     ),
 
+    atapi.BooleanField('auto_exclude_from_nav',
+        languageIndependent=1,
+        widget=atapi.BooleanWidget(
+              label=_(u'Exclude images from navigation'),
+              description=_(u"Whether new images, uploaded via multi-upload, should be excluded from navigation."),
+        ),
+        required=False,
+        searchable=False,
+        default=True,
+    ),
+
     atapi.IntegerField('page_size',
         languageIndependent=1,
         widget=atapi.IntegerWidget(
